# PV-Vision
Image analysis of defects on solar cells.

This package allows you to analyze electroluminescene (EL) 
images of PV module. The methods in this package include EL image preprocessing, defective 
cell identification, crack segmentation, maximum isolated area prediction, etc.

## Installation
1. Install from source
```bash
git clone https://github.com/hackingmaterials/pv-vision.git
cd pv-vision
pip install .
```
2. Install from Pypi
```bash
pip install pv-vision
```

## Usage
Import the package
```python
import pv_vision
```

Read [tutorials](https://github.com/hackingmaterials/pv-vision/tree/main/tutorials)

## Citation
Please cite our papers if you use our tool or dataset.

Citation format can be found in our [github](https://github.com/hackingmaterials/pv-vision/)